==> etiketti-2023.1.25.tar.gz: etiketti-2023.1.25/README.md <==
# Etiketti

Label (Finnish: etiketti) some files.

[License: MPL-2.0](https://git.sr.ht/~sthagen/etiketti/tree/default/item/LICENSE) only for the pikepedf dependency - all contributions added are licensed per MIT.

Third party dependencies are documented in the folder [third-party](docs/docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![downloads](https://pepy.tech/badge/etiketti/month)](https://pepy.tech/project/etiketti)
[![wheel](https://img.shields.io/pypi/wheel/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![supported-versions](https://img.shields.io/pypi/pyversions/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![supported-implementations](https://img.shields.io/pypi/implementation/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)

## Documentation

User and developer [documentation of etiketti](https://codes.dilettant.life/docs/etiketti).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of etiketti](https://todo.sr.ht/~sthagen/etiketti).

## Primary Source repository

The main source of `etiketti` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `etiketti` are:

* [on codeberg](https://codeberg.org/sthagen/etiketti) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/etiketti) - a collection of tools useful for software development.

## Status

Prototype.

**Note**: The default branch is `default`.

==> etiketti-2023.6.18.tar.gz: etiketti-2023.6.18/README.md <==
# Etiketti

Label (Finnish: etiketti) some files.

[License: MPL-2.0](https://git.sr.ht/~sthagen/etiketti/tree/default/item/LICENSE) only for the pikepedf dependency - all contributions added are licensed per MIT.

Third party dependencies are documented in the folder [third-party](docs/docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![downloads](https://pepy.tech/badge/etiketti/month)](https://pepy.tech/project/etiketti)
[![wheel](https://img.shields.io/pypi/wheel/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![supported-versions](https://img.shields.io/pypi/pyversions/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![supported-implementations](https://img.shields.io/pypi/implementation/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)

## Documentation

User and developer [documentation of etiketti](https://codes.dilettant.life/docs/etiketti).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of etiketti](https://todo.sr.ht/~sthagen/etiketti).

## Primary Source repository

The main source of `etiketti` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `etiketti` are:

* [on codeberg](https://codeberg.org/sthagen/etiketti) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/etiketti) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Status

Prototype.

**Note**: The default branch is `default`.
